<?php

namespace Vmc\Appointment\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Vmc\Appointment\Http\Requests\AppointmentRequest;
use Vmc\Appointment\Interfaces\AppointmentRepositoryInterface;
use Vmc\Appointment\Models\Appointment;

class AppointmentUserController extends BaseController
{
    /**
     * Initialize appointment controller.
     *
     * @param type AppointmentRepositoryInterface $appointment
     *
     * @return type
     */
    public function __construct(AppointmentRepositoryInterface $appointment)
    {
        $this->repository = $appointment;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Vmc\Appointment\Repositories\Criteria\AppointmentUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AppointmentRequest $request)
    {
        $appointments = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('appointment::appointment.names'));

        return $this->theme->of('appointment::user.appointment.index', compact('appointments'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Appointment $appointment
     *
     * @return Response
     */
    public function show(AppointmentRequest $request, Appointment $appointment)
    {
        Form::populate($appointment);

        return $this->theme->of('appointment::user.appointment.show', compact('appointment'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AppointmentRequest $request)
    {

        $appointment = $this->repository->newInstance([]);
        Form::populate($appointment);

        $this->theme->prependTitle(trans('appointment::appointment.names'));
        return $this->theme->of('appointment::user.appointment.create', compact('appointment'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AppointmentRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $appointment = $this->repository->create($attributes);

            return redirect(trans_url('/user/appointment/appointment'))
                -> with('message', trans('messages.success.created', ['Module' => trans('appointment::appointment.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Appointment $appointment
     *
     * @return Response
     */
    public function edit(AppointmentRequest $request, Appointment $appointment)
    {

        Form::populate($appointment);
        $this->theme->prependTitle(trans('appointment::appointment.names'));

        return $this->theme->of('appointment::user.appointment.edit', compact('appointment'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Appointment $appointment
     *
     * @return Response
     */
    public function update(AppointmentRequest $request, Appointment $appointment)
    {
        try {
            $this->repository->update($request->all(), $appointment->getRouteKey());

            return redirect(trans_url('/user/appointment/appointment'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('appointment::appointment.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AppointmentRequest $request, Appointment $appointment)
    {
        try {
            $this->repository->delete($appointment->getRouteKey());
            return redirect(trans_url('/user/appointment/appointment'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('appointment::appointment.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
