<?php

namespace Vmc\Appointment\Http\Controllers;
use Litepie\Appointment\Http\Requests\AppointmentRequest;
use Litepie\Appointment\Models\Appointment;

trait AppointmentWorkflow {
	
    /**
     * Workflow controller function for appointment.
     *
     * @param Model   $appointment
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AppointmentRequest $request, Appointment $appointment, $step)
    {

        try {

            $appointment->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('appointment::appointment.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/appointment/appointment/' . $appointment->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/appointment/appointment/' . $appointment->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for appointment.
     *
     * @param Model   $appointment
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Appointment $appointment, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $appointment->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('appointment::appointment.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('appointment::admin.appointment.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('appointment::admin.appointment.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('appointment::admin.appointment.message', $data)->render();

        }

    }
}