<?php

namespace Vmc\Appointment\Policies;

use App\User;
use Vmc\Appointment\Models\Appointment;

class AppointmentPolicy
{

    /**
     * Determine if the given user can view the appointment.
     *
     * @param User $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function view(User $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $appointment->user_id;
    }

    /**
     * Determine if the given user can create a appointment.
     *
     * @param User $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('appointment.appointment.create');
    }

    /**
     * Determine if the given user can update the given appointment.
     *
     * @param User $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function update(User $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $appointment->user_id;
    }

    /**
     * Determine if the given user can delete the given appointment.
     *
     * @param User $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function destroy(User $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $appointment->user_id;
    }

    /**
     * Determine if the given user can verify the given appointment.
     *
     * @param User $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function verify(User $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('appointment.appointment.verify') 
        && $user->is('manager')
        && $appointment->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given appointment.
     *
     * @param User $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function approve(User $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
