<?php

namespace Vmc\Appointment\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Vmc\Appointment\Models\Appointment;

class AppointmentAction
{
    /**
     * Perform the complete action.
     *
     * @param Appointment $appointment
     *
     * @return Appointment
     */
    public function complete(Appointment $appointment)
    {
        try {
            $appointment->status = 'complete';
            return $appointment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Appointment $appointment
     *
     * @return Appointment
     */public function verify(Appointment $appointment)
    {
        try {
            $appointment->status = 'verify';
            return $appointment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Appointment $appointment
     *
     * @return Appointment
     */public function approve(Appointment $appointment)
    {
        try {
            $appointment->status = 'approve';
            return $appointment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Appointment $appointment
     *
     * @return Appointment
     */public function publish(Appointment $appointment)
    {
        try {
            $appointment->status = 'publish';
            return $appointment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Appointment $appointment
     *
     * @return Appointment
     */
    public function archive(Appointment $appointment)
    {
        try {
            $appointment->status = 'archive';
            return $appointment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Appointment $appointment
     *
     * @return Appointment
     */
    public function unpublish(Appointment $appointment)
    {
        try {
            $appointment->status = 'unpublish';
            return $appointment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
