<?php

namespace Vmc\Appointment\Workflow;

use Vmc\Appointment\Models\Appointment;
use Validator;

class AppointmentValidator
{

    /**
     * Determine if the given appointment is valid for complete status.
     *
     * @param Appointment $appointment
     *
     * @return bool / Validator
     */
    public function complete(Appointment $appointment)
    {
        return Validator::make($appointment->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given appointment is valid for verify status.
     *
     * @param Appointment $appointment
     *
     * @return bool / Validator
     */
    public function verify(Appointment $appointment)
    {
        return Validator::make($appointment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given appointment is valid for approve status.
     *
     * @param Appointment $appointment
     *
     * @return bool / Validator
     */
    public function approve(Appointment $appointment)
    {
        return Validator::make($appointment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given appointment is valid for publish status.
     *
     * @param Appointment $appointment
     *
     * @return bool / Validator
     */
    public function publish(Appointment $appointment)
    {
        return Validator::make($appointment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given appointment is valid for archive status.
     *
     * @param Appointment $appointment
     *
     * @return bool / Validator
     */
    public function archive(Appointment $appointment)
    {
        return Validator::make($appointment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given appointment is valid for unpublish status.
     *
     * @param Appointment $appointment
     *
     * @return bool / Validator
     */
    public function unpublish(Appointment $appointment)
    {
        return Validator::make($appointment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
